@@ -6,7 +6,7 @@ Kafka::Exceptions - Perl Kafka API exception definitions.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Exceptions> version 0.9001 .
+This documentation refers to C<Kafka::Exceptions> version 0.9010 .
 
 =cut
 
@@ -18,7 +18,7 @@ use warnings;
 
 # ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '0.9001';
+our $VERSION = '0.9010';
 
 use Exporter qw(
     import
@@ -56,6 +56,9 @@ use Exception::Class (
 use Kafka qw(
     %ERROR
 );
+use Kafka::Internals qw(
+    format_message
+);
 
 #-- declarations ---------------------------------------------------------------
 
@@ -207,7 +210,7 @@ sub throw_args {
 
     return(
         code    => $error_code,
-        message => $ERROR{ $error_code }.( $description ? ": $description" : q{} ),
+        message => format_message( '%s%s', $ERROR{ $error_code }, $description ? ": $description" : '' ),
     );
 }
 
