@@ -6,7 +6,7 @@ Kafka::Internals - Constants and functions used internally.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Internals> version 0.9001 .
+This documentation refers to C<Kafka::Internals> version 0.9010 .
 
 =cut
 
@@ -18,7 +18,7 @@ use warnings;
 
 # ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '0.9001';
+our $VERSION = '0.9010';
 
 use Exporter qw(
     import
@@ -38,12 +38,16 @@ our @EXPORT_OK = qw(
     debug_level
     _isbig
     _get_CorrelationId
+    format_message
+    format_reference
 );
 
 #-- load the modules -----------------------------------------------------------
 
+use overload;
 use Carp;
 use Const::Fast;
+use Data::Dumper ();
 use Params::Util qw(
     _INSTANCE
 );
@@ -222,6 +226,81 @@ sub debug_level {
     return ${ "${class}::DEBUG" };
 }
 
+=head2 format_reference
+
+    say format_reference( $object );
+
+Dumps reference using preconfigured L<Data::Dumper>. Produces less verbose
+output than default L<Data::Dumper> settings.
+
+=cut
+
+my $dumper;
+my $empty_array = [];
+
+sub format_reference {
+    my ( $value ) = @_;
+
+    unless( $dumper ) {
+        $dumper = Data::Dumper->new( $empty_array )
+            ->Indent( 0 )
+            ->Terse( 1 )
+            ->Quotekeys( 0 )
+            ->Sortkeys( 1 )
+            ->Useperl( 1 )      # XS version seems to have a bug which sometimes results in modification of original object
+            ->Sparseseen( 1 )   # speed up since we don't use "Seen" hash
+        ;
+    }
+
+    my $r;
+    if (
+            overload::Overloaded( $value ) &&
+            overload::Method( $value, '""' )
+        ) {
+        $r = "$value";  # force stringification
+    } else {
+        $r = $dumper->Values( [ $value ] )->Dump;
+        $dumper->Reset->Values( $empty_array );
+    }
+
+    return $r;
+}
+
+=head2 format_message
+
+    $string = format_message( 'Object %d loaded. Status: %s', $id, $message );
+
+Returns string formatted using printf-style syntax.
+
+If there are more than one argument and the first argument contains C<%...>
+conversions, arguments are converted to a string message using C<sprintf()>. In this case, undefined
+values are printed as C<< <undef> >> and references are converted to strings using L</format_reference>.
+
+=cut
+sub format_message {
+    my $format = shift // return;
+
+    my $got = scalar @_;
+
+    return $format unless $got && $format =~ /\%/;
+
+    my $expected = 0;
+    while ( $format =~ /(%%|%[^%])/g ) {
+        next if $1 eq '%%'; # don't count escape sequence
+        ++$expected;
+    }
+
+    Carp::cluck "Wrong number of arguments: $expected vs $got" unless $got == $expected;
+
+    return sprintf $format, map {
+        !defined $_
+            ? '<undef>'
+            : ref $_
+                ? format_reference( $_ )
+                : $_
+    } @_;
+}
+
 #-- private attributes ---------------------------------------------------------
 
 #-- private methods ------------------------------------------------------------
